package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.CommentMapper;
import com.example.wholeestate.dao.CustomerMapper;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.Comment;
import com.example.wholeestate.model.Customer;
import com.example.wholeestate.model.SysUser;
import com.example.wholeestate.service.ICommentService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 评论表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class CommentServiceImpl extends ServiceImpl<CommentMapper, Comment> implements ICommentService {

    @Autowired
    private CommentMapper commentMapper;

    @Autowired
    private CustomerMapper customerMapper;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean addComment(String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Comment comment = JSONObject.parseObject(parameter, Comment.class);
        comment.setCreateDate(LocalDateTime.now());
        comment.setStatus(1);

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("customer_id", comment.getCustomerId());
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError("评论用户不存在!");
            return responseBean;
        }

        comment.setCommentId(idGen.nextId()+"");
        comment.setCustomerName(customer.getCustomerName());
        comment.setAvatar(customer.getAvatar());

        int insert = commentMapper.insert(comment);
        if (insert <= 0) {
            responseBean.addError("评论失败!");
            return responseBean;
        }
        responseBean.addSuccess("评论成功!");
        return responseBean;
    }

    @Override
    public ResponseBean getCommentList(String commentType, String mainId, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<Comment> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        QueryWrapper<Comment> commentQueryWrapper = new QueryWrapper<>();
        commentQueryWrapper.eq("comment_type", commentType);
        commentQueryWrapper.eq(StringUtils.isNotBlank(mainId),"main_id", mainId);
        IPage<Comment> commentIPage = commentMapper.selectPage(page, commentQueryWrapper);

        responseBean.addSuccess(commentIPage);
        return responseBean;
    }

    @Override
    public ResponseBean getWxCommentList(String commentType, String mainId, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<Comment> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        QueryWrapper<Comment> commentQueryWrapper = new QueryWrapper<>();
        commentQueryWrapper.eq("comment_type", commentType);
        commentQueryWrapper.eq("main_id", mainId);
        IPage<Comment> commentIPage = commentMapper.selectPage(page, commentQueryWrapper);
        List<Comment> records = commentIPage.getRecords();
        records.forEach(e -> {
            QueryWrapper<Comment> childCommentQuery = new QueryWrapper<>();
            childCommentQuery.eq("parent_id", e.getCommentId());
            List<Comment> comments = commentMapper.selectList(childCommentQuery);
            e.setChildComment(comments);
        });

        responseBean.addSuccess(commentIPage);
        return responseBean;
    }

    @Override
    public ResponseBean addWxComment(String openid, String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Comment comment = JSONObject.parseObject(parameter, Comment.class);
        comment.setCreateDate(LocalDateTime.now());
        comment.setStatus(1);

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError("评论用户不存在!");
            return responseBean;
        }

        comment.setCommentId(idGen.nextId()+"");
        comment.setCustomerName(customer.getCustomerName());
        comment.setAvatar(customer.getAvatar());
        comment.setCustomerId(customer.getCustomerId());

        int insert = commentMapper.insert(comment);
        if (insert <= 0) {
            responseBean.addError("评论失败!");
            return responseBean;
        }
        responseBean.addSuccess("评论成功!");
        return responseBean;
    }
}
